# Meet my UUIDv7 Generator

## How To Install
```bash
pip install UUIDv7gen
```

## Example Usage
```python

from UUIDv7gen import UUIDv7, is_valid_uuid7

# To Generate a UUID
uuid = UUIDv7()
print(uuid)

# To Validate a UUID
print(is_valid_uuid7(uuid))
```
